%bcond_with enc_x264
%bcond_with dec_avcodec2
%bcond_with csc_swscale

# These are nececessary as the _with_foo is *not* defined if the
# --with flag isn't specifed, and we need to have the --without
# specified option in that case.
%if !%{with enc_x264}
%define _with_enc_x264 --without-enc_x264
%endif

%if !%{with dec_avcodec2}
%define _with_dec_avcodec2 --without-dec_avcodec2
%endif

%if !%{with csc_swscale}
%define _with_csc_swscale --without-csc_swscale
%endif

# Remove private provides from .so files in the python_sitearch directory
%global __provides_exclude_from ^%{python_sitearch}/.*\\.so$

Name:           xpra
Version:        0.16.3
Release:        3%{?dist}
Summary:        Remote display server for applications and desktops

License:        GPLv2+ and BSD and LGPLv3+ and MIT
URL:            https://www.xpra.org/
Source0:        https://xpra.org/src/%{name}-%{version}.tar.xz

BuildRequires:  python2-devel pygobject2-devel pygtk2-devel
BuildRequires:  libXtst-devel
BuildRequires:  libxkbfile-devel
BuildRequires:  Cython
BuildRequires:  desktop-file-utils
BuildRequires:  libvpx-devel
BuildRequires:  libwebp-devel
BuildRequires:  libappstream-glib
BuildRequires:  cups-devel
BuildRequires:  redhat-lsb-core

%if %{with enc_x264}
BuildRequires:  x264-devel
%endif
%if %{with dec_avcodec2} || %{with csc_swscale}
%BuildRequires:  ffmpeg-devel
%endif

%if 0%{fedora} >= 24
Requires:       python2-pillow
Requires:       python2-cups
Requires:       python2-pyopengl
%else
Requires:       python-pillow
Requires:       python-cups
Requires:       PyOpenGL
%endif
%if 0%{fedora} >= 23
Requires:       python-gobject
Requires:       python2-lz4
Requires:       python2-rencode
Suggests:       python2-pyopencl
%else
Requires:       pygobject2
Requires:       python-rencode
Requires:       python-lz4
%endif
Requires:       dbus-python
Requires:       dbus-x11
Requires:       xorg-x11-server-utils
Requires:       xorg-x11-drv-dummy
Requires:       xorg-x11-xauth
Requires:       pygtkglext
Requires:       numpy
Requires:       gstreamer1
Requires:       gstreamer1-plugins-base gstreamer1-plugins-good
Requires:       pulseaudio pulseaudio-utils
Requires:       cups-filesystem
Requires:       shared-mime-info

# Needed to create the xpra group
Requires(pre):  shadow-utils

%description
Xpra is "screen for X": it allows you to run X programs, usually on a remote
host, direct their display to your local machine, and then to disconnect from
these programs and reconnect from the same or another machine, without losing
any state. It gives you remote access to individual applications.

Xpra is "rootless" or "seamless": programs you run under it show up on your
desktop as regular programs, managed by your regular window manager.
Sessions can be accessed over SSH, or password protected over plain TCP sockets.
Xpra is usable over reasonably slow links and does its best to adapt to changing
network bandwidth constraints.

%package html5
Summary:        html5 server and client support for xpra
Requires:       %{name} = %{version}-%{release}
# websockify is required to allow xpra to listen for an html5 client
Requires:       python-websockify
Requires:       js-web-socket-js
Requires:       js-jquery
Provides:       bundled(js-jquery-ui) = 1.10.4
Requires:       js-zlib

%description html5
This package adds websockify support to allow xpra to listen for http
connections, and also the xpra html5 client.

# Note: cups-config not in buildroot during srpm build, so we use the
# conditional execution to silence erros during srpm build.
%global cupslibdir %(cups-config --serverbin 2> /dev/null || echo "/usr/lib/cups")

%prep
%setup -q

%build
CFLAGS="%{optflags}" %{__python} setup.py build \
    --verbose \
    --with-vpx \
    --with-webp \
    %{?_with_enc_x264} \
    %{?_with_dec_avcodec2} \
    %{?_with_csc_swscale} \
%if 0%{?fedora} >= 23
    --with-csc_opencl \
%endif
    --with-Xdummy \
    --with-Xdummy_wrapper

%install
%{__python} setup.py install \
    --skip-build \
    --root %{buildroot} \
    --verbose \
    --with-vpx \
    --with-webp \
    %{?_with_enc_x264} \
    %{?_with_dec_avcodec2} \
    %{?_with_csc_swscale} \
%if 0%{?fedora} >= 23
    --with-csc_opencl \
%endif
    --with-Xdummy \
    --with-Xdummy_wrapper


#move icon to proper directory
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mv %{buildroot}%{_datadir}/icons/xpra.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/

#remove doc stuff from /usr/share
rm -f \
    %{buildroot}%{_datadir}/xpra/README \
    %{buildroot}%{_datadir}/xpra/COPYING

#drop shebangs from python_sitearch
find %{buildroot}%{python_sitearch}/xpra -name '*.py' \
    -exec sed -i '1{\@^#!/usr/bin/env python@d}' {} \;

#fix permissions on shared objects
find %{buildroot}%{python_sitearch}/xpra -name '*.so' \
    -exec chmod 0755 {} \;

# delete any bundled SWFs - binary content forbidden by packaging
# guidelines
find %{buildroot}%{_datadir}/xpra -name '*.swf' -exec rm {} \;

# Use system js-query rather than the bundled one
ln -sf ../../../javascript/jquery/2/jquery.min.js \
    %{buildroot}%{_datadir}/xpra/www/include/jquery.min.js

# Use system web-socket-js rather than the bundled one
rm -rf %{buildroot}%{_datadir}/xpra/www/include/web-socket-js
ln -sf ../../../javascript/web-socket-js \
    %{buildroot}%{_datadir}/xpra/www/include/web-socket-js

# Use system js-zlib instead of bundled one on Fedora >= 21
%if 0%{?fedora} >= 21
for file in deflate.min.js inflate.min.js ; do
    ln -sf ../../../javascript/zlib/$file \
       %{buildroot}%{_datadir}/xpra/www/include/$file
done
%endif

# Ensure all .js files are not executeable
find %{buildroot}%{_datadir}/xpra/www/include -name '*.js' \
    -exec chmod 0644 {} \;

# Create this directory for sharing sockets
mkdir -p %{buildroot}%{_localstatedir}/run/xpra/

appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/appdata/xpra.appdata.xml


%check
desktop-file-validate %{buildroot}%{_datadir}/applications/xpra.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/xpra_launcher.desktop


%pre
getent group xpra >/dev/null || groupadd -r xpra


%post
/usr/bin/update-desktop-database &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
/usr/bin/update-desktop-database &> /dev/null || :

if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%dir %{_sysconfdir}/xpra
%config(noreplace) %{_sysconfdir}/xpra/xorg.conf
%config(noreplace) %{_sysconfdir}/xpra/xpra.conf
%{_bindir}/xpra
%{_bindir}/xpra_Xdummy
%{_bindir}/xpra_launcher
%{python_sitearch}/xpra
%{python_sitearch}/*.egg-info
%{_datadir}/applications/xpra*.desktop
%{_datadir}/icons/hicolor/48x48/apps/xpra.png
%{_mandir}/man1/xpra.1.*
%{_mandir}/man1/xpra_launcher.1.*
%{_datadir}/appdata/xpra.appdata.xml
%{_datadir}/mime/packages/application-x-xpraconfig.xml
%{_datadir}/xpra/icons
%{cupslibdir}/backend/xpraforwarder
%{_prefix}/lib/tmpfiles.d/xpra.conf
%ghost %dir %{_localstatedir}/run/xpra
%doc README COPYING NEWS

%files html5
%{_datadir}/xpra/www

%changelog
* Thu Apr 14 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.3-3
- Fix deps for F22

* Thu Apr 14 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.3-2
- Correctly enable use of shared sockets with the xpra group
- Require(pre) for shadow-utils
- Create xpra group during %%pre
- Create and ghost own %%{_localstatedir}/run/lightdm/

* Thu Mar 24 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.3-1
- Update to 0.16.3

* Mon Feb 29 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-8
- Properly enable opencl support on Fedora 23
- Change PyOpenGL requires to python2-opengl on f24 and higher

* Sun Feb 28 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-7
- Change python-imaging dep to python[2]-pillow
- Change python-cups to python2-cups of F24 and higher

* Sun Feb 28 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-6
- Remove python-numeric Requires
- Change python-rencode dep to python2-rencode
- Change python-lz4 dep to python2-lz4

* Mon Feb 22 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-5
- Fix cupslibdir macro to not spew errors during SRPM build

* Fri Feb 19 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-4
- Move icon files back into main package

* Fri Feb 19 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-3
- Drop xpra-0.16.2-move-to-var-run.patch - broken

* Fri Feb 19 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-2
- Add pyopencl Suggests for F23
- No longer move the run script to /var/run - breaks other clients
- Use XDG_RUNTIME_DIR for socket and logs (BZ 1309872)

* Fri Feb 19 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.2-1
- Uodate to 0.16.2 (BZ 1301357)
- Replace gstreamer Requires with gstreamer1 Requires (BZ 1309811)
- Require python-gobject (BZ 1309811)
- No longer Require gstreamer-python (BZ 1309811)
- Require xorg-x11-xauth (BZ 1309804)
- Require dbus-x11 (BZ 1309827)

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.16.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 26 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.1-2
- Split html5 support out into subpackage

* Tue Jan 26 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.1-1
- Update to 0.16.1

* Thu Jan  7 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.0-3
- Re-add ~/.xpra to socket-dirs for backwards compatibility as second
  in search order

* Thu Jan  7 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.0-2
- Add patch to Move sockets, log files, script files from ~/.xpra to
  /var/run/user/$UID/xpra

* Thu Jan  7 2016 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.16.0-1
- Update to 0.16.0

* Tue Dec 29 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.10-2
- Rebuild for libwebp 0.5.0

* Sat Dec 19 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.10-1
- Update to 0.15.10

* Wed Dec  2 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.9-1
- Update to 0.15.9

* Tue Dec  1 2015 Tom Callaway <spot@fedoraproject.org> - 0.15.8-3
- rebuild for libvpx 1.5.0

* Mon Nov 30 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.8-2
- Use same options for build and install
- Add csc_opencl support for Fedora 24 and later

* Sat Nov 14 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.8-1
- Update to 0.15.8
- Fix typo in spec file

* Wed Sep 16 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.7-1
- Update to 0.15.7
- Fix typo in spec changelog

* Wed Sep 16 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.6-1
- Update to 0.15.6

* Wed Sep  2 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.15.5-1
- Update to 0.15.5
- Drop patches related to color encoding

* Fri Aug 21 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.4-4
- Remove xpra-r10393.patch and add xpra-r10396.patch and xpra-r10399.patch
  as second attempt to fix the color encoding issues

* Fri Aug 21 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.4-3
- No longer revert r9983, but include xpra-r10393.patch to fix the
  color encoding

* Wed Aug  5 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.4-2
- Add patch to revert upstream commit r9983 which breaks color encodding

* Tue Aug  4 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.4-1
- Update to 0.15.4
- Add missing release tag to previous rpm changelog entry

* Tue Jul 14 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.3-1
- Update to 0.15.3
- Remove xpra-0.15.2-9768.patch
- Add BuildRequires for redhat-lsb-core to make lsb_release available
  at build time (used to detect system type)
- Add --with-Xdummy and --with-Xdummy_wrapper to install options to
  ensure Xdummy is used

* Thu Jul  2 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.2-2
- Add small fix from upsteam (rev 9768)

* Thu Jul  2 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.2-1
- Update to 0.15.2
- Add Requires for python-lz4 and python-cups

* Mon Jun 22 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.1-1
- Update to 0.15.1
- Add Requires shared-mime-info for (/usr/share/mime/packages ownership)
- Add /usr/share/mime/packages/application-x-xpraconfig.xml file

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jun  4 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.0-2
- Remove extraneous second definition of cupslibdir

* Mon Jun  1 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.15.0-1
- Update to 0.15.0
- Add BuildRequires for cups-devel and Requires for cups-filesystem
- Replace mention of avcodec with avcodec2
- Drop xpra-unbundle-rencode.patch, and no longer patch to use system
  rencode
- Drop xpra-0.14-stop-using-void-driver.patch
- Drop xpra-0.14.22-fedora22-xorg.patch

* Wed May 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.24-1
- Update to 0.14.24
- Remove Requires for xorg-x11-server-Xvfb
- Remove upstreamed appdata patch

* Tue May 26 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-5
- Add patch to correctly locate Xorg binary in Fedora 22 onwards (BZ 1224678)

* Tue Apr 28 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-4
- Patch appdata file to have more information and proper paragraph
  ending period so validation works

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-3
- Remove Requires for xorg-x11-drv-void

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-2
- Validate and own /usr/share/appdata/xpra.appdata.xml
- Add BuildRequires libappstream-glib

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.22-1
- Update to 0.14.22

* Mon Apr 27 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-5
- Add patch to remove reference to the xorg void driver in xorg.conf (BZ #1215527)

* Mon Apr  6 2015 Tom Callaway <spot@fedoraproject.org> - 0.14.21-4
- rebuild for libvpx 1.4.0

* Tue Mar 24 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-3
- Update license tag from GPLv2+ to GPLv2+ and BSD and LGPLv3+ and MIT

* Mon Mar 23 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-2
- Add conditionals for building with ffmpeg and x264 support, disabled
  by default
- Remove Provides for bundled(js-web-socket-js)
- Use system js-zlib on Fedora >= 21
- On Fedora < 21 add Provides for bundled(js-zlib)

* Wed Mar 18 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.21-1
- Update to 0.14.21

* Wed Mar 18 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-6
- Unbundle js-query even on Fedora 20

* Wed Mar 18 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-5
- Unbundle web-socket-js

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-4
- Add --with-Xdummy and --with-Xdummy_wrapper build options since Xorg
  not installed at build time so autodetection fails

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-3
- Use js-jquery package only on F22 or later - not available on
  earlier distros

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-2
- Update Summary to be more descriptive of package
- Use packaged js-jquery
- Add provides for bundled(js-jquery-ui) and bundled(js-web-socket-js)
- Build with vpx and webp support enabled
- Remove any installed SWF files
- Remove executable flag for all .js files
- Remove Requires for python-webm

* Tue Mar  3 2015 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 0.14.19-1
- Update to upstream 0.14.19
- Add BuildRequires for libxkbfile-devel
- No longer need to unbundle webp
- Rework and rename patch for unbundling of rencode

* Fri Oct 18 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.10.6-1
- new upstream release 0.10.6
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-October/000726.html

* Tue Oct 08 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.10.4-2
- reenable webp support
- fix webm unbundling to support importing all modules in the webm package
- require latest python-webm so it matches what's bundled upstream

* Mon Oct 07 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.10.4-1
- rebase to 0.10.4
- don't ship webm stuff that doesn't work without ffmpeg anyway

* Thu Aug 01 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.8-1
- new upstream release 0.9.8
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-July/000615.html
- use HTTPS for URL and Source0

* Wed Jul 03 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.6-1
- new upstream release 0.9.6
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-June/000552.html

* Thu Jun 27 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.5-1
- new upstream release 0.9.5
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-June/000549.html

* Thu May 30 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.4-1
- new upstream release 0.9.4
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000539.html

* Mon May 13 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.2-1
- new upstream release 0.9.2
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000525.html

* Fri May 10 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.1-1
- new upstream release 0.9.1
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-May/000522.html

* Tue May 07 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.0-2
- fix rencode __version__ importing

* Thu May 02 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.9.0-1
- new upstream release 0.9.0
  http://lists.devloop.org.uk/pipermail/shifter-users/2013-April/000479.html
- delete the bundled code in prep instead of inside the patches
- don't bother including parti; it's going away upstream soon
- merge python-wimpiggy into main xpra package; it won't be seperated upstream soon

* Thu Apr 18 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-4
- unbundle rencode and webm
- fix equality operator in Requires
- drop unnecessary multiple copies of NEWS
- don't remove buildroot

* Thu Apr 11 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-3
- drop unmet dependency on gstreamer-plugins-ugly
- fix permissions on shared objects
- add scriptlets necessary for icon/desktop file

* Thu Mar 28 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-2
- disable codecs prohibited in Fedora

* Thu Mar 14 2013 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.8.8-1
- initial package
